==> nui_animation-0.0.1.tar.gz: lib/nui_flip_animation.dart <==
import 'dart:developer';
import 'dart:math';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_animation/nui_animation.dart';

enum FlipDirection{
  VERTICAL,
  HORIZONTAL
}

class NUIFlipAnimation extends StatefulWidget {
  NUIFlipAnimation({@required this.initialChild, this.flippedChild, this.duration, this.direction: FlipDirection.VERTICAL, this.endAnimationListener, Key key}): super(key: key);
  final Widget initialChild;
  final Widget flippedChild;
  final Duration duration;
  final FlipDirection direction;
  final EndAnimationListener endAnimationListener;
  @override
  _NUIFlipAnimationState createState() => _NUIFlipAnimationState();
}

class _NUIFlipAnimationState extends State<NUIFlipAnimation> with SingleTickerProviderStateMixin {
  AnimationController _animationController;
  Animation _animation;
  AnimationStatus _animationStatus = AnimationStatus.dismissed;
  bool _isDisposed = false;

  @override
  void initState() {
    super.initState();
    _animationController = AnimationController(vsync: this, duration: widget.duration ?? Duration(seconds: 1));
    _animation = Tween(end: 1.0, begin: 0.0).animate(_animationController)
      ..addListener(() {
        if(!_isDisposed) {
          setState(() {});
        }
      })
      ..addStatusListener((status) {
        _animationStatus = status;
      });
  }

  @override
  void dispose(){
    super.dispose();
    _isDisposed = true;
    _animationController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Transform(
        alignment: FractionalOffset.center,
        transform: widget.direction == FlipDirection.VERTICAL ? (Matrix4.identity()
          ..setEntry(3, 2, 0.002)
          ..rotateX(pi * _animation.value)) : (Matrix4.identity()
          ..setEntry(3, 2, 0.002)
          ..rotateY(pi * _animation.value)),
        child: GestureDetector(
          onTap: () {
            if(_animation.value > 0.0000 && _animation.value < 1.0000) return;

            if (_animationStatus == AnimationStatus.dismissed) {
              _animationController.forward();
            } else {
              _animationController.reverse();
            }
          },
          child: _animation.value <= 0.5 ? widget.initialChild : widget.flippedChild ?? widget.initialChild
        ),
      );
  }
}

void sampleFlipAnimation(BuildContext context, {Widget initialChild, Widget flippedChild, Duration duration, FlipDirection direction: FlipDirection.VERTICAL}){
  final animation = NUIFlipAnimation(
      initialChild: initialChild ?? Container(
        color: Colors.blueAccent,
        width: 300,
        height: 200,
        child: Icon(
          Icons.ac_unit,
          color: Colors.white,
          size: 50,
        ),
      ),
    flippedChild: flippedChild ?? Container(
      color: Colors.red,
      width: 300,
      height: 200,
      child: Icon(
        Icons.ac_unit,
        color: Colors.white,
        size: 50,
      ),
    ),
    duration: duration ?? Duration(seconds: 2),
    direction: direction ?? FlipDirection.VERTICAL,
  );

  showDialog(
    context: context,
    builder: (context){
        return Container(
          width: double.infinity,
          height: double.infinity,
          alignment: Alignment.center,
          child: animation,
        );
    }
  );
}

==> nui_animation-1.0.1.tar.gz: lib/nui_flip_animation.dart <==
import 'dart:math';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_animation/nui_animation.dart';

enum FlipDirection{
  VERTICAL,
  HORIZONTAL
}

class NUIFlipAnimation extends StatefulWidget {
  NUIFlipAnimation({
    required this.initialChild,
    this.flippedChild,
    this.duration,
    this.direction = FlipDirection.VERTICAL,
    this.endAnimationListener,
    Key? key
  }): super(key: key);
  final Widget initialChild;
  final Widget? flippedChild;
  final Duration? duration;
  final FlipDirection direction;
  final EndAnimationListener? endAnimationListener;
  @override
  _NUIFlipAnimationState createState() => _NUIFlipAnimationState();
}

class _NUIFlipAnimationState extends State<NUIFlipAnimation> with SingleTickerProviderStateMixin {
  late AnimationController _animationController;
  late Animation _animation;
  AnimationStatus _animationStatus = AnimationStatus.dismissed;
  bool _isDisposed = false;

  @override
  void initState() {
    super.initState();
    _animationController = AnimationController(vsync: this, duration: widget.duration ?? Duration(seconds: 1));
    _animation = Tween(end: 1.0, begin: 0.0).animate(_animationController)
      ..addListener(() {
        if(!_isDisposed) {
          setState(() {});
        }
      })
      ..addStatusListener((status) {
        _animationStatus = status;
      });
  }

  @override
  void dispose(){
    super.dispose();
    _isDisposed = true;
    _animationController.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Transform(
        alignment: FractionalOffset.center,
        transform: widget.direction == FlipDirection.VERTICAL ? (Matrix4.identity()
          ..setEntry(3, 2, 0.002)
          ..rotateX(pi * _animation.value)) : (Matrix4.identity()
          ..setEntry(3, 2, 0.002)
          ..rotateY(pi * _animation.value)),
        child: GestureDetector(
          onTap: () {
            if(_animation.value > 0.0000 && _animation.value < 1.0000) return;

            if (_animationStatus == AnimationStatus.dismissed) {
              _animationController.forward();
            } else {
              _animationController.reverse();
            }
          },
          child: _animation.value <= 0.5 ? widget.initialChild : widget.flippedChild ?? widget.initialChild
        ),
      );
  }
}

void sampleFlipAnimation(BuildContext context, {Widget? initialChild, Widget? flippedChild, Duration? duration, FlipDirection direction: FlipDirection.VERTICAL}){
  final animation = NUIFlipAnimation(
      initialChild: initialChild ?? Container(
        color: Colors.blueAccent,
        width: 300,
        height: 200,
        child: Icon(
          Icons.ac_unit,
          color: Colors.white,
          size: 50,
        ),
      ),
    flippedChild: flippedChild ?? Container(
      color: Colors.red,
      width: 300,
      height: 200,
      child: Icon(
        Icons.ac_unit,
        color: Colors.white,
        size: 50,
      ),
    ),
    duration: duration ?? Duration(seconds: 2),
    direction: direction ?? FlipDirection.VERTICAL,
  );

  showDialog(
    context: context,
    builder: (context){
        return Container(
          width: double.infinity,
          height: double.infinity,
          alignment: Alignment.center,
          child: animation,
        );
    }
  );
}
